#
# spec file for package davix
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib lib%{name}0
%define v_maj 0
%define v_min 8
%define v_pat 10
Name:           davix
Version:        0.8.10
Release:        1.3
Summary:        File management over HTTP-based protocols
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Web/Utilities
URL:            https://davix.web.cern.ch/davix/docs/devel
Source:         https://github.com/cern-fts/davix/releases/download/R_%{v_maj}_%{v_min}_%{v_pat}/davix-%{version}.tar.gz
BuildRequires:  cmake >= 3.0
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  cmake(GTest)
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(gsoapssl++)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(uuid)

%description
Davix does file management over HTTP-based protocols. It focuses on
remote I/O and data management of large collections of files. There
is support for the WebDav, Amazon S3, Microsoft Azure, and HTTP
protocols.

It provides a C++ library offering an HTTP API, a remote I/O API, and
a POSIX compatibility layer. It also provides several utilities for
file transfer, large collections of files management and large files
management.

%package -n %{shlib}
Summary:        Library offering davix APIs for HTTP, remote I/O, and POSIX compatibility layer
Group:          System/Libraries

%description -n %{shlib}
This package provides the shared libraries for davix with APIs for
HTTP, remote I/O, and a POSIX compatibility layer.

%package devel
Summary:        Headers and sources for developing software using davix
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}

%description devel
This package provides the headers and sources needed for developing
applications using davix.

%prep
%autosetup -p1

%build
%cmake \
  -DEMBEDDED_LIBCURL=FALSE \
  -DENABLE_THIRD_PARTY_COPY:BOOL=TRUE \
  -DCMAKE_POLICY_VERSION_MINIMUM=3.5 \
  %{nil}
%cmake_build

%install
%cmake_install

# REMOVE NON-STD DOC FILES, TO BE CORRECTLY INSTALLED USING %%doc macro
rm -fr %{buildroot}%{_datadir}/doc/davix

%check
%ctest

%ldconfig_scriptlets -n %{shlib}

%files
%doc README.md RELEASE-NOTES.md
%license LICENSE
%{_bindir}/davix-cp
%{_bindir}/davix-get
%{_bindir}/davix-http
%{_bindir}/davix-ls
%{_bindir}/davix-mkdir
%{_bindir}/davix-mv
%{_bindir}/davix-put
%{_bindir}/davix-rm
%{_bindir}/davix-tester
%{_bindir}/davix-unit-tests
%{_mandir}/man1/davix-*.1%{?ext_man}

%files -n %{shlib}
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/libdavix.3%{?ext_man}

%changelog
* Wed Apr 23 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.10:
  * [gh#cern-fts/davix#137] - Davix 0.8.8 is not thread safe.
- Changes from version 0.8.9:
  - Davix PerformanceMarkers are not propagated upwards for short
    HTTP-TPC transfers.
- Changes from version 0.8.8:
  * Bug fixes
  - Davix redirection cache stuck in redirect loops.
  - [gh#cern-fts/davix#120] - Out of Date RapidJSON dependency
    causing compile failure.
  - [gh#cern-fts/davix#122] - S3 listing ignores "IsTruncated =
    true" property.
  - [gh#cern-fts/davix#126] - Crash on badly formed davix-cp
    command.
  - [gh#cern-fts/davix#129] - Remove non-compiling assignment
    operator.
  - [gh#cern-fts/davix#130] - compiler error in
    rapidjson/document.h.
  - [gh#cern-fts/davix#131] - Segmentation fault with long
    Authorization header.
  * Improvements
  - Davix error messages should print backend library used.
  - Remove bundled "googletest" from Davix.
  - Improve error handling when failing to read GCloud
    credential file.
  - [gh#cern-fts/davix#125] - Allow forcing of bundled
    rapidjson.
- Drop 057b4fa188b6b8afdb34cc6b7d103c78e73c1001.patch:
  incorporated upstream.
- Add BuildRequires: cmake(GTest) now needed to build and run
  tests.
* Sat Sep 28 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add 057b4fa188b6b8afdb34cc6b7d103c78e73c1001.patch: Upstream
  commit to disable the "GcloudTest::UrlSigning" test as the
  GCloud V4 signature involves the current timestamp, which leads
  to non-static results.
* Wed Jul 17 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.7:
  * Davix does not hide lower-case Authorization headers for
    HTTP/2
  * [gh#cern-fts/davix#120] Out of Date RapidJSON dependency
    causing compile failure
  * [gh#cern-fts/davix#114] Support 64-bit off_t on 32-bit systems
    (LFS)
  * [gh#cern-fts/davix#119] Use system rapidjson, fall back to
    bundled
  * [gh#cern-fts/davix#123] Implement multipart streaming for
    DavPosix::write()
  * [gh#cern-fts/davix#124] Fix s3 dirlisting to follow the
    istruncated/nextmarker
- Drop davix-no-hardcoded-rapidjson-includes.patch: upstreamed.
* Wed May  1 2024 Atri Bhattacharya <badshah400@gmail.com>
- Use system available curl and rapidjson instead of bundled
  instances. The use of system rapidjson has the nice side-effect
  of no longer failing to build against GCC14.
- Add davix-no-hardcoded-rapidjson-includes.patch -- Do not hard
  code the location of rapidjson header, and allow system package
  to be used if available [gh#cern-fts/davix#119].
- Enable third-party copy program davix-cp, add BuildRequires:
  pkgconfig(gsoapssl++).
- Run tests as part of %%check.
* Wed Apr 10 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.6:
  * Davix header parsing is case-sensitive for libcurl backend.
  * libxml 2.12.0 breaks Gfal2/Davix listing.
  * Incorrect IPv4 reported for HTTP-TPC transfers that don't send
    "RemoteConnections" marker.
  * [gh#cern-fts/davix#113] - Use sed in a more POSIX compliant
    way.
  * Long Authorization header xxxx token string print in Davix.
  * [gh#cern-fts/davix#105] - Do not hardcode error numbers.
  * [gh#cern-fts/davix#110] - Support the NVHPC compiler.
- Empty %%check section for rpmlint.
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.5:
  * [gh#cern-fts/davix#107] - CVE-2023-38545 in bundled curl
    library.
  * [gh#cern-fts/davix#106] - Add git mailmap file.
- Use macros to define version, to avoid changing version related
  strings in multiple places.
* Wed Feb 15 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.8.4:
  * New Features
  - [DMC-1358] - Provide involved transfer hosts via the Copy API
  - [davix/issues/101] - Introspect redirections for HTTP TPC xfers
  * Improvements
  - [DMC-1361] - Improve Davix header logs propagation via logging callback function
  - [davix/pull/99] - Re-enable test to be run with CTest (or make test / ninja test)
  * Issues
  - [davix/issues/98] - Infinite loop in davix slow unit tests when using external libcurl
  - [davix/issues/100] - Unit tests fail when run by more than one user on the same machine
  - [davix/issues/102] - CVE-2022-32221 in bundled curl library
  - [davix/pull/103] - Don't downgrade the C++ version (bugzilla#2163827)
* Thu Nov  3 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.8.3:
  * Bug fixes
  - [DMC-1345] - Segfault when encountering invalid redirection URL
  - [DMC-1346] - Segfault because of empty NeonSession object
* Fri Jul 15 2022 Timothy Brown <stimut@gmail.com>
- Update to version 0.8.2
  * New Features
  - [DMC-1310] - Parse IP stack performance markers in Davix HTTP-TPC
  - [DMC-1320] - Compute S3v4 URI signatures for HTTP TPC calls
  * Issues
  - [davix/issues/97] - Address copyrighted song lyrics in codebase
  - [root-project/root/issues/9072] - HTTP basic authentication and Davix
  * Improvements
  - [DMC-1318] - Better HTTP Copy error message in Davix
  - [davix/pull/95] - Fix CMake warning
  - Improve build and release scripts to also accept tags containing release number
* Mon May  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.8.1:
  * Epic
  - [DMC-1267] - Davix with libcurl backend
  - Huge refactoring to accommodate both libneon and libcurl backends,
    as well as improved testing
  * Bug fixes
  - [D-MC-1259] - Gfal2-python pread(offset, count): Partial Content
    request not working against EOS storage
  - [DMC-1279] - Davix with libcurl backend does not load certificate
    via callback functions
  - [DMC-1291] - Davix fails to parse IPv6-format hostname during
    certificate verification
  - [davix/issues/71] - davix-get failing auth with DAVIX_USE_LIBCURL
  - [DMC-1209] - Davix Redirection Cache causes Segfault when
    encountering relative path
  - [DMC-1243] - Davix hangs if url starts with 'https' is used with
    S3/Swift credentials in command
  - [davix/pull/54] - Really add '\0' after printed X.509 data
  - [davix/pull/66] - Initialize session factory members
  - [davix/pull/70] - Fix return value of HttpIO::readFull
  * New Features
  - [DMC-1221] - Introduce a filter to avoid exposing sensitive
    information (such as bearer tokens) in Davix debug output
  - [DMC-1238] - Add SWIFT support in Davix
  - [DMC-1268] - Add CS3API support in Davix
  * Changes
  - [davix/pull/83] - Remove reva-specific credentials management
  * Improvements
  - [DMC-1025] - Allow HEAD-free open through posix API
  - [DMC-1245] - Add leading 0 to Adler32 checksum format in Davix
  * Drop davix-non-void-function.patch
  * Drop davix-link-against-libdl.patch
* Tue May 12 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.7.6:
  * Bug fixes:
  - [DMC-1190] - Unhandled DavixException in secondary thread
    during multi-range simulation.
  - [DMC-1191] - Memory leak in function trying to detect S3
    region.
  - Recognize OpenSSL 'bad decrypt' error message as
    CredDecryptionError.
  - Fix error handling for proxy delegation.
  * [DMC-1181] - Implement proper, abstract data provider class
    for davix HttpIOChain.
  * Refactoring and improvements to davix-tester.
- Changes from version 0.7.5:
  * Bug fixes:
  - Enable use of dav:// and davs:// in third party copies.
  - Fix third party copies when the server presents multiple
    certificate delegation endpoints.
  - Prevent davix from infinite-looping when the server abruptly
    terminates the connection during TPC.
  * Add ability to cancel ongoing TPC transfers through
    user-supplied callback.
  * Continued refactoring to eventually allow the use of libcurl
    as HTTP backend in davix.
  * In-source builds are no longer supported, and explicitly
    prevented by CMake.
- Minor updates to patches using quilt to apply cleanly (only line
  number changes).
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias and unrealized future visions from descriptions.
* Wed Aug 21 2019 Atri Bhattacharya <badshah400@gmail.com>
- Add davix-non-void-function.patch: Fix non-void function that
  returns nothing, patch sent upstream.
- Add davix-link-against-libdl.patch: Link against libdl; patch
  taken from debian package build.
* Fri Aug 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
